@@ -18,6 +18,9 @@ class AxeBase():
         self.nom = other.nom
         self.unite = other.unite
 
+    def __eq__(self, other):
+        return self.unite == other.unite
+
     def __str__(self):
         return self.nom + ", " + self.unite
 if __name__ == "__main__":
