@@ -4,7 +4,7 @@ import copy
 import os, sys
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
 
-class Trigger():
+class TriggerBase():
     def __init__(self):
         self.seuil = None
         self.montant = None
@@ -12,8 +12,9 @@ class Trigger():
         self.pretrigger_souple = None
         self.hysteresys = None
 
-    def tester_trigger(self):
+    def tester(self):
         return self.seuil != None
 
 if __name__ == "__main__":
-    pass
+    t = TriggerBase()
+    print(t.tester())
