@@ -21,7 +21,7 @@ from signaux.signal_complet import SignalComplet
 __all__ = ["SignalCarre"]
 
 def generer_portion_carre(axe_x_base, F, alpha, tr):
-    xmin, xmax = axe_x_base.calculer_liste_xmin_xmax()
+    xmin, xmax = axe_x_base.lire_liste_xmin_xmax()
     n = int(np.floor((xmin-tr)*F))
 
     t0 = n/F+tr
