@@ -12,7 +12,7 @@ sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.par
 
 import base.constantes_base as cst
 
-from signaux.signal_7_filtre import Signal7Filtre
+from signaux.signal_8_tronque import Signal8Tronque
 from base.axe_x_base import AxeXBase
 
 import numpy as np
@@ -21,7 +21,7 @@ import matplotlib.pyplot as plt
  
 __all__ = []
 
-class SignalComplet(Signal7Filtre):
+class SignalComplet(Signal8Tronque):
     pass
 
 
