@@ -24,7 +24,7 @@ def linspace_(umin, umax, N):
     return np.linspace(umin, umax, N+1)[:N]
 
 def generer_portion_triangle(axe_x_base, F, alpha, tr):
-    xmin, xmax = axe_x_base.calculer_liste_xmin_xmax()
+    xmin, xmax = axe_x_base.lire_liste_xmin_xmax()
     n = int(np.floor((xmin-tr)*F))
 
     t0 = n/F+tr
