@@ -94,4 +94,6 @@ if __name__ == "__main__":
     # s1 = Signal("cosinus", 2e2, nom_voie = "EA0", seuil = 0, phi=-np.pi/2)
     # s1.tracer()
     s1 = Signal(voie = "SA1", F = 440, Vpp = 19, liste_tmin_tmax = [0, 5], Te = 1/40e3).quantifier(8)
+    s2 = s1.copier()
+    s3 = s1+s2
     s1.tracer()
\ No newline at end of file
