@@ -21,29 +21,29 @@ class Sysam4Methodes(Sysam3Test):
 
     def calculer_arguments_config_entrees(self):
         if "entree" in self.chaine_mode:
-            voies = [s.lire_voie_base().calculer_numero() for s in self.liste_entrees]
-            calibres = [s.lire_voie_base().calibre for s in self.liste_entrees]
-            diff = [s.lire_voie_base().calculer_numero() for s in self.liste_entrees_diffs]
+            voies = [s._Signal6Sysam__lire_voie_base().calculer_numero() for s in self.liste_entrees]
+            calibres = [s._Signal6Sysam__lire_voie_base().calibre for s in self.liste_entrees]
+            diff = [s._Signal6Sysam__lire_voie_base().calculer_numero() for s in self.liste_entrees_diffs]
             return voies, calibres, diff
         return None
 
     def calculer_arguments_config_echantillon(self):
         if "entree" in self.chaine_mode:
-            if self.base_de_temps_entrees:
-                techant = self.base_de_temps_entrees.calculer_Te() / base.voie_base.T_sysam
-                nbpoints = self.base_de_temps_entrees.calculer_N()
+            if self.axe_x_base_entrees:
+                techant = self.axe_x_base_entrees.lire_Xe() / base.voie_base.T_sysam
+                nbpoints = self.axe_x_base_entrees.lire_N()
                 return techant, nbpoints
         return None
 
     def calculer_arguments_config_trigger(self):
         if "trigger" in self.chaine_mode:
             st = self.liste_triggers[0]
-            voie = st.lire_voie_base().calculer_numero()
-            seuil = st.lire_trigger_base().seuil
-            montant = 1 if st.lire_trigger_base().montant == True else 0
-            pretrigger = st.lire_trigger_base().pretrigger
-            pretrigger_souple = 1 if st.lire_trigger_base().pretrigger_souple == True else 0
-            hysteresys = 1 if st.lire_trigger_base().hysteresys == True else 0
+            voie = st._Signal6Sysam__lire_voie_base().calculer_numero()
+            seuil = st._Signal6Sysam__lire_trigger_base().seuil
+            montant = 1 if st._Signal6Sysam__lire_trigger_base().montant == True else 0
+            pretrigger = st._Signal6Sysam__lire_trigger_base().pretrigger
+            pretrigger_souple = 1 if st._Signal6Sysam__lire_trigger_base().pretrigger_souple == True else 0
+            hysteresys = 1 if st._Signal6Sysam__lire_trigger_base().hysteresys == True else 0
             return voie, seuil, montant, pretrigger, pretrigger_souple, hysteresys
         return None
 
@@ -51,9 +51,9 @@ class Sysam4Methodes(Sysam3Test):
         if "sortie"+str(n) in self.chaine_mode and "synchrone" not in self.chaine_mode:
             nsortie = n
             s = self.liste_sortie1[0] if n == 1 else self.liste_sortie2[0]
-            techant = s.lire_base_de_temps().calculer_Te() / base.voie_base.T_sysam
-            tensions = s.lire_vecteur_signal()
-            repetition = -1 if s.lire_voie_base().repetition else 0
+            techant = s._PlotBase__lire_axe_x_base().lire_Xe() / base.voie_base.T_sysam
+            tensions = s.lire_vecteur_y()
+            repetition = -1 if s._Signal6Sysam__lire_voie_base().repetition else 0
 
             return nsortie, techant, tensions, repetition
 
@@ -68,20 +68,20 @@ class Sysam4Methodes(Sysam3Test):
 
     def calculer_arguments_acquerir_avec_sorties(self):
         if "synchrone" in self.chaine_mode:
-            tensions1 = self.liste_sortie1[0].lire_vecteur_signal() if "sortie1" in self.chaine_mode else np.zeros(1)
-            tensions2 = self.liste_sortie2[0].lire_vecteur_signal() if "sortie2" in self.chaine_mode else np.zeros(1)
+            tensions1 = self.liste_sortie1[0].lire_vecteur_y() if "sortie1" in self.chaine_mode else np.zeros(1)
+            tensions2 = self.liste_sortie2[0].lire_vecteur_y() if "sortie2" in self.chaine_mode else np.zeros(1)
             return tensions1, tensions2
         return None
 
 
 if __name__ == "__main__":
-    liste_tmin_tmax = [0, 1e-4]
+    liste_xmin_xmax = [0, 1e-4]
     Te = 1e-5
-    s1 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "EA0", Te = Te, seuil = 0, pretrigger = 3)
-    s2 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "DIFF2", Te = Te)
-    s3 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "EA3", Te = Te)
-    s4 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA1", Te = Te)
-    s5 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA2", Te = Te)
+    s1 = Signal(liste_xmin_xmax =liste_xmin_xmax, nom_voie = "EA0", Te = Te, seuil = 0, pretrigger = 3)
+    s2 = Signal(liste_xmin_xmax =liste_xmin_xmax, nom_voie = "DIFF2", Te = Te)
+    s3 = Signal(liste_xmin_xmax =liste_xmin_xmax, nom_voie = "EA3", Te = Te)
+    s4 = Signal(liste_xmin_xmax =liste_xmin_xmax, nom_voie = "SA1", Te = Te)
+    s5 = Signal(liste_xmin_xmax =liste_xmin_xmax, nom_voie = "SA2", Te = Te)
     
     sysam = Sysam4Methodes([s1, s2, s3, s4, s5])
 
@@ -89,7 +89,7 @@ if __name__ == "__main__":
     # N = 10
     # liste_signaux = []
     # for i in range(N):
-    #     liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+    #     liste_signaux.append(SignalGBF(liste_xmin_xmax = liste_xmin_xmax, Te = Te))
 
     # liste_signaux[0].configurer_voie("EA1")
     # liste_signaux[1].configurer_voie("SA1")
