@@ -80,14 +80,14 @@ class SysamSP5(Sysam4Methodes):
             self.sysam.acquerir_avec_sorties(*self.calculer_arguments_acquerir_avec_sorties())
             self.mettre_a_jour_entrees()
         elif "entree" in self.chaine_mode and "sortie" in self.chaine_mode:
-            xmin, xmax = self.axe_x_base_entrees.calculer_liste_xmin_xmax()
+            xmin, xmax = self.axe_x_base_entrees.lire_liste_xmin_xmax()
             self.sysam.declencher_sorties(*self.calculer_arguments_declencher_sorties())
             if xmin != 0:
                 time.sleep(xmin)
             self.sysam.acquerir()
             self.mettre_a_jour_entrees()
         elif "entree" in self.chaine_mode and "sortie" not in self.chaine_mode:
-            xmin, xmax = self.axe_x_base_entrees.calculer_liste_xmin_xmax()
+            xmin, xmax = self.axe_x_base_entrees.lire_liste_xmin_xmax()
             self.sysam.acquerir()
             self.mettre_a_jour_entrees()            
         elif "sortie" in self.chaine_mode and "entree" not in self.chaine_mode:
